@@ -475,6 +475,83 @@ class ProxyGeneratorTest extends TestCase
         );
     }
 
+    /**
+     * @requires PHP >= 8.1.0
+     */
+    public function testPhp81IntersectionType()
+    {
+        $className = PHP81IntersectionTypes::class;
+
+        if ( ! class_exists('Doctrine\Tests\Common\ProxyProxy\__CG__\PHP81IntersectionTypes', false)) {
+            $metadata = $this->createClassMetadata($className, ['id']);
+
+            $proxyGenerator = new ProxyGenerator(__DIR__ . '/generated', __NAMESPACE__ . 'Proxy');
+            $this->generateAndRequire($proxyGenerator, $metadata);
+        }
+
+        self::assertStringContainsString(
+            'setFoo(\Traversable&\Countable $foo): \Traversable&\Countable',
+            file_get_contents(__DIR__ . '/generated/__CG__DoctrineTestsCommonProxyPHP81IntersectionTypes.php')
+        );
+    }
+
+    /**
+     * @requires PHP >= 8.1.0
+     */
+    public function testPhp81NeverType()
+    {
+        $className = PHP81NeverType::class;
+
+        if ( ! class_exists('Doctrine\Tests\Common\ProxyProxy\__CG__\PHP81NeverType', false)) {
+            $metadata = $this->createClassMetadata($className, ['id']);
+
+            $proxyGenerator = new ProxyGenerator(__DIR__ . '/generated', __NAMESPACE__ . 'Proxy');
+            $this->generateAndRequire($proxyGenerator, $metadata);
+        }
+
+        self::assertStringContainsString(
+            '__get($name): never',
+            file_get_contents(__DIR__ . '/generated/__CG__DoctrineTestsCommonProxyPHP81NeverType.php')
+        );
+
+        self::assertStringContainsString(
+            '__set($name, $value): never',
+            file_get_contents(__DIR__ . '/generated/__CG__DoctrineTestsCommonProxyPHP81NeverType.php')
+        );
+
+        self::assertStringContainsString(
+            'finishHim(): never',
+            file_get_contents(__DIR__ . '/generated/__CG__DoctrineTestsCommonProxyPHP81NeverType.php')
+        );
+    }
+
+    /**
+     * @requires PHP >= 8.1.0
+     */
+    public function testEnumDefaultInPublicProperty() : void
+    {
+        $className = Php81EnumPublicPropertyType::class;
+
+        if ( ! class_exists('Doctrine\Tests\Common\ProxyProxy\__CG__\Php81EnumPublicPropertyType', false)) {
+            $metadata = $this->createClassMetadata($className, ['id']);
+
+            $metadata->method('hasField')->will($this->returnValue(true));
+
+            $proxyGenerator = new ProxyGenerator(__DIR__ . '/generated', __NAMESPACE__ . 'Proxy');
+            $this->generateAndRequire($proxyGenerator, $metadata);
+        }
+
+        $this->assertStringContainsString(
+            'use Doctrine;',
+            file_get_contents(__DIR__ . '/generated/__CG__DoctrineTestsCommonProxyPhp81EnumPublicPropertyType.php')
+        );
+
+        $object = new \Doctrine\Tests\Common\ProxyProxy\__CG__\Doctrine\Tests\Common\Proxy\Php81EnumPublicPropertyType();
+        $object = unserialize(serialize($object));
+
+        $this->assertSame($object->isEnum, \Doctrine\Tests\Common\Proxy\YesOrNo::YES);
+    }
+
     /**
      * @param string  $className
      * @param mixed[] $ids
